@@ -1,7 +1,7 @@
 export.dyadic <-
 function(blauObj){
   if (is.null(blauObj$dyadic)){
-    print("Nothing to export.")
+    message("Nothing to export.")
   }
   else{
     return(blauObj$dyadic)
